==> gallery2_2.0.2.orig.tar.gz: gallery2/index.php <==
<?php
/*
 * $RCSfile: index.php,v $
 *
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2005 Bharat Mediratta
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
 */
/**
 * @version $Revision: 1.16 $ $Date: 2005/08/23 03:48:55 $
 * @package Gallery
 * @author Bharat Mediratta <bharat@menalto.com>
 */

/*
 * This script will just redirect to main.php. But the Location header requires
 * an absolute url to conform with HTTP/1.1
 * (Include bootstrap.inc in case config.php overrides GALLERY_MAIN_PHP)
 */
require(dirname(__FILE__) . '/bootstrap.inc');
require(dirname(__FILE__) . '/modules/core/classes/GalleryUrlGenerator.class');

/* The REQUEST_URI can either be /path/index.php or just /path/. Get rid of index.php.* */
$path = preg_replace('|^(/(?:[^?#/]+/)*).*|', '$1', GalleryUrlGenerator::getCurrentRequestUri());

header('Location: ' . GalleryUrlGenerator::makeUrl($path) . GALLERY_MAIN_PHP);
?>

==> gallery2_2.1.2.orig.tar.gz: gallery2/index.php <==
<?php
/*
 * $RCSfile: index.php,v $
 *
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2006 Bharat Mediratta
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
 */
/**
 * @version $Revision: 1.19 $ $Date: 2006/03/06 05:33:32 $
 * @package Gallery
 * @author Bharat Mediratta <bharat@menalto.com>
 */

/*
 * This script will just redirect to main.php. But the Location header requires
 * an absolute url to conform with HTTP/1.1
 * (Include bootstrap.inc in case config.php overrides GALLERY_MAIN_PHP)
 */
require_once(dirname(__FILE__) . '/bootstrap.inc');
require_once(dirname(__FILE__) . '/modules/core/classes/GalleryUrlGenerator.class');

/* The REQUEST_URI can either be /path/index.php or just /path/. Get rid of index.php.* */
$path = GalleryUrlGenerator::getCurrentRequestUri();
if (preg_match('|^(/(?:[^?#/]+/)*)(.*)|', $path, $matches)) {
    $path = $matches[1] . GALLERY_MAIN_PHP;
    if (!empty($matches[2]) && ($pos = strpos($matches[2], '?')) !== false) {
	$path .= substr($matches[2], $pos);
    }
}

$configBaseUri = @$gallery->getConfig('baseUri');

$urlGenerator =& new GalleryUrlGenerator();
$urlGenerator->init(!empty($configBaseUri) ? $configBaseUri : null);

header('Location: ' . $urlGenerator->makeUrl($path));
?>
